
import { useEffect } from 'react';
import Navigation from '@/components/Navigation';
import Footer from '@/components/Footer';
import { Card, CardContent } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Download, FileText, CheckCircle, Calendar, Users, MessageSquare } from 'lucide-react';
import NewsletterSignup from '@/components/NewsletterSignup';
import SEOHead from '@/components/SEOHead';

const Parents = () => {
  const schema = {
    "@context": "https://schema.org",
    "@type": "Organization",
    "name": "The IEP Coach - Special Education Advocacy and Support",
    "description": "Professional advocacy services supporting families, students, and educators through expert IEP representation, legal education consulting, and special education resources.",
    "mainEntity": {
      "@type": "DefinedTermSet",
      "name": "Special Education Advocacy Keywords",
      "url": "https://www.theiepcoach.com",
      "hasDefinedTerm": [
        { "@type": "DefinedTerm", "name": "Professional Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Support" },
        { "@type": "DefinedTerm", "name": "Expert IEP Advocacy" },
        { "@type": "DefinedTerm", "name": "Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Education Services" },
        { "@type": "DefinedTerm", "name": "IEP Coach" },
        { "@type": "DefinedTerm", "name": "Special Education Advocacy" },
        { "@type": "DefinedTerm", "name": "Family Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Services" },
        { "@type": "DefinedTerm", "name": "Education Advocacy Services" },
        { "@type": "DefinedTerm", "name": "Special Education Advocacy Support" },
        { "@type": "DefinedTerm", "name": "Educational Advocacy" },
        { "@type": "DefinedTerm", "name": "Professional Advocacy Consultant" },
        { "@type": "DefinedTerm", "name": "Legal Education Advocate Services" },
        { "@type": "DefinedTerm", "name": "Disability Education Support" },
        { "@type": "DefinedTerm", "name": "Expert IEP Consultant" },
        { "@type": "DefinedTerm", "name": "Best IEP Advocate Services" },
        { "@type": "DefinedTerm", "name": "TheIEPCoach" },
        { "@type": "DefinedTerm", "name": "Educational Legal Advocacy" }
      ]
    }
  };
  const resources = [
    {
      title: "The 13 Disability Categories Under IDEA",
      description: "Learn about all special education eligibility categories and how we support each",
      icon: Users,
      link: "/iep-support-by-disability"
    },
    {
      title: "IEP Preparation Checklist",
      description: "Essential items to review and prepare before your IEP meeting",
      icon: CheckCircle,
      link: "/iep-preparation-checklist"
    },
    {
      title: "Sample Evaluation Request Letter",
      description: "Template for requesting comprehensive evaluations for your child",
      icon: FileText
    },
    {
      title: "Behavior Data Tracking Template",
      description: "Systematic way to document behaviors and track patterns",
      icon: Calendar
    },
    {
      title: "Timeline Tracker",
      description: "When to request meetings, responses, and reevaluations",
      icon: Calendar
    },
    {
      title: "Parent Vision Statement Guide",
      description: "How to articulate your hopes and goals for your child's future",
      icon: MessageSquare
    }
  ];

  return (
    <div className="min-h-screen">
      <SEOHead
        title="IEP Advocacy & Support for Parents | The IEP Coach"
        description="IEP advocacy and support for parents navigating special education. ARD meeting preparation, 504 plans, behavior support, and individualized health plans. Get the support your child deserves."
        keywords="ARD, Special Education, Resource, Functional Academics, Behavior Support, MDR, IHP, Individualized Health Plan, IDEA, Sped, IEP advocacy for parents, special education support, ARD meetings, 504 plan help, parent rights special education, IEP meeting preparation, special education advocate, IDEA advocacy, parent support special needs"
        canonical="https://www.theiepcoach.com/parents"
        openGraph={{
          title: "IEP Advocacy & Support for Parents - The IEP Coach",
          description: "IEP advocacy and support for parents navigating special education. ARD meeting preparation, 504 plans, behavior support, and individualized health plans. Get the support your child deserves.",
          image: "https://www.theiepcoach.com/lovable-uploads/0a09e87f-544f-4502-bfe9-30850c1f8cdb.png",
          url: "https://www.theiepcoach.com/parents"
        }}
        schema={schema}
      />
      <Navigation />
      
      {/* Hero Section - Updated to match About page */}
      <section className="bg-gradient-to-br from-primary to-blue-800 text-white py-16">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h1 className="text-4xl lg:text-5xl font-heading font-bold mb-6">
            <span className="text-orange-400">Resources & Tools for Parents</span>
          </h1>
          <p className="text-xl text-blue-100 max-w-3xl mx-auto mb-8">
            Practical tools and templates to help you navigate your child's special education journey with confidence.
          </p>
          <div className="flex justify-center">
            <NewsletterSignup />
          </div>
        </div>
      </section>

      {/* Resources Section */}
      <section className="py-12">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-heading font-bold text-primary mb-4">
              Resources for Parents
            </h2>
            <p className="text-lg text-gray-600 max-w-2xl mx-auto">
              Ready-to-use resources to help you prepare for meetings, document concerns, and advocate effectively for your child.
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8 mb-16">
            {resources.map((resource, index) => {
              const IconComponent = resource.icon;
              return (
                <Card key={index} className="hover:shadow-lg transition-shadow">
                  <CardContent className="p-6">
                    <div className="bg-accent/10 rounded-full w-16 h-16 flex items-center justify-center mx-auto mb-4">
                      <IconComponent className="h-8 w-8 text-accent" />
                    </div>
                    <h3 className="font-heading font-semibold text-lg mb-3 text-center">
                      {resource.title}
                    </h3>
                    <p className="text-gray-600 text-center mb-4">
                      {resource.description}
                    </p>
                    <div className="text-center">
                      {resource.link ? (
                        <Button variant="outline" size="sm" className="text-accent border-accent hover:bg-accent hover:text-white" asChild>
                          <a href={resource.link}>View Resource</a>
                        </Button>
                      ) : (
                        <Button variant="outline" size="sm" className="text-accent border-gray-300 cursor-not-allowed" disabled>
                          Coming Soon
                        </Button>
                      )}
                    </div>
                  </CardContent>
                </Card>
              );
            })}
          </div>
        </div>
      </section>

      {/* Key Rights Section */}
      <section className="py-12 bg-gray-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-heading font-bold text-primary mb-4">
              Know Your Rights Under IDEA
            </h2>
            <p className="text-lg text-gray-600 max-w-2xl mx-auto">
              Understanding your family's rights is the foundation of effective advocacy.
            </p>
          </div>

          <div className="grid md:grid-cols-2 gap-8">
            <Card>
              <CardContent className="p-8">
                <h3 className="font-heading font-semibold text-xl mb-4 text-primary">
                  Procedural Safeguards
                </h3>
                <ul className="space-y-3 text-gray-600">
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Prior written notice for any changes to your child's program
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Consent required for initial evaluations and services
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Access to all educational records
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Right to independent educational evaluations
                  </li>
                </ul>
              </CardContent>
            </Card>

            <Card>
              <CardContent className="p-8">
                <h3 className="font-heading font-semibold text-xl mb-4 text-primary">
                  FAPE & LRE
                </h3>
                <ul className="space-y-3 text-gray-600">
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Free and Appropriate Public Education (FAPE)
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Least Restrictive Environment (LRE) placement
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Individualized Education Program (IEP) tailored to your child
                  </li>
                  <li className="flex items-start">
                    <CheckCircle className="h-5 w-5 text-accent mr-3 mt-0.5 flex-shrink-0" />
                    Related services to support educational goals
                  </li>
                </ul>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Blog & Learning Section */}
      <section className="py-12">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl lg:text-4xl font-heading font-bold text-primary mb-4">
              Read & Learn More
            </h2>
            <p className="text-lg text-gray-600 max-w-2xl mx-auto">
              We regularly share blog posts and free guides on important special education topics.
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-6">
            <Card className="hover:shadow-lg transition-shadow">
              <CardContent className="p-6">
                <h3 className="font-semibold text-lg mb-3 text-primary">
                  Securing Your Rights at Evaluation Meetings
                </h3>
                <p className="text-gray-600 text-sm">
                  Essential strategies for ensuring your voice is heard during evaluation discussions.
                </p>
              </CardContent>
            </Card>

            <Card className="hover:shadow-lg transition-shadow">
              <CardContent className="p-6">
                <h3 className="font-semibold text-lg mb-3 text-primary">
                  When to Seek an Independent Educational Evaluation
                </h3>
                <p className="text-gray-600 text-sm">
                  Understanding your rights and when an IEE might benefit your child.
                </p>
              </CardContent>
            </Card>

            <Card className="hover:shadow-lg transition-shadow">
              <CardContent className="p-6">
                <h3 className="font-semibold text-lg mb-3 text-primary">
                  Choosing Between a Coach, Advocate, or Attorney
                </h3>
                <p className="text-gray-600 text-sm">
                  Navigate the different types of support available for your family.
                </p>
              </CardContent>
            </Card>

            <Card className="hover:shadow-lg transition-shadow">
              <CardContent className="p-6">
                <h3 className="font-semibold text-lg mb-3 text-primary">
                  Strengthening Communication with Your IEP Team
                </h3>
                <p className="text-gray-600 text-sm">
                  Build positive relationships while advocating effectively for your child.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-12 bg-accent/5">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <h2 className="text-3xl font-heading font-bold mb-6">
            <span className="text-orange-400">Get Started Today</span>
          </h2>
          <p className="text-lg text-gray-600 mb-8">
            Schedule a free consultation to discuss your child's needs and how we can support your family.
          </p>
          <Button size="lg" className="bg-accent hover:bg-accent/90 text-white" asChild>
            <a href="/contact">Schedule Your Free Consultation</a>
          </Button>
        </div>
      </section>

      <Footer />
    </div>
  );
};

export default Parents;
